cyl

package module
v0.0.0-...-56d0176 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 24, 2019 License: MIT Imports: 0 Imported by: 0

README

cyl

Area and Volume for Cylinder

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Cylinder

type Cylinder struct {
	// contains filtered or unexported fields
}

Cylinder To create the cylinder Object

func (Cylinder) BaseArea

func (c Cylinder) BaseArea() float32

BaseArea To calculate the Base Area of the Cylinder

func (Cylinder) Set

func (c Cylinder) Set(r, h float32)

Set This will set the Radius and Height for the cylinder

func (Cylinder) Volume

func (c Cylinder) Volume() float32

Volume To calculate the Volume of the Cylinder

Jump to